<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Névjegy </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Szerző</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Támogatás</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licenc </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Parancsikon</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Töröl</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Kép készítése</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Kurzort is</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Késleltetés</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>mp</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Képkészítési mód</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Kép mutatása a rögzített ablakban</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>kép másolása vágólapra</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Kép feltöltése</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Kép megnyitása szülőkönyvtárban</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Kép mentése</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Műveletek beállításai</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Művelet</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Vízjel-kép szükséges</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Addj vízjelet-képet az Opciók&gt; Beállítások&gt; Kiemelés&gt; Frissítés menüponttal</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Sima festő útvonal</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Ha engedélyezve van, kiüríti a tollat és a
jelölő útvonalakat a rajz befejezése után.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Simasági faktor</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>A simasági tényező növekedésével
csökken a toll és a jelölő pontossága,
de simábbá teszi.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Kiemelés beállításai</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Képernyő mentése program indításkor az alapértelmezett módon</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Alkalmazás stílusa</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Beállítja az alkalmazás stílusát, amely meghatározza a grafikus felhasználói felület megjelenését és hangulatát.
A módosításhoz érvényesítéséhez a program újraindítása szükséges.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Alkalmazás beállítások</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Az új képernyőmentéseket automatikusan másolja a vágólapra</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Tallózás</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Közreműködők:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Spanyol fordítás</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Holland fordítás</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Orosz fordítás</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Norvég fordítás</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Francia fordítás</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Lengyel fordítás</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Figyelem - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Rajzolj (kijelölő) területet az egérrel</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>A teljes képernyő rögzítése, beleértve az összes monitort</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Aktuális képernyő rögzítése, ahol az egér található</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Aktív ablak rögzítése, ahol a fókusz van</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Az egérmutató alatt lévő ablak rögzítése</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Képernyőkép rögzítése a legutoljára használt kijelölés szerint</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Az adományokat mindig szívesen fogadjuk</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation type="unfinished">Terület</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation type="unfinished">Legutoljára használt kijelölés</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished">Teljes képernyő (minden monitor)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation type="unfinished">Aktuális képernyő</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation type="unfinished">Aktív ablak</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation type="unfinished">Kurzor alatti ablak</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Felhasználónév</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation type="unfinished">Sikeres feltöltés</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Globális gyorsbillentyűk bekapcsolása</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Kijelölt terület rögzítése</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Teljes képernyő rögzítése</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Aktuális képernyő rögzítése</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Aktív ablak rögzítése</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Kurzor alatti ablak rögzítése</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Globális gyorsbillentyűk</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Legutoljára használt kijelölés szerinti rögzítés</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Töröl</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Egérkurzor rögzítése a képernyőképen</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Az egérkurzor látszódni fog
a képernyőképen.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Képlopás</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur előznény</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Idő bélyegző</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Link törlése</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation type="unfinished">Az imgur.com-ra való feltöltés befejeződött!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation type="unfinished">Új azonosító, próbáld meg újra feltölteni…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation type="unfinished">Az Imgur azonosító lejárt, igényelj egy újat…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Névtelen feltöltés kényszerítése</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Mindig másolja az Imgur linket a vágólapra</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Ügyfél ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Ügyfél titkosító</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Írd be az imgur Pin kódot, ami egy azonosítóra lesz cserélve.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>PIN beszerzése</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Azonosító beszerzése</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur előzmény</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur feltöltő</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Várakozás az imgur.com-ra…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>imgur.com azonosító sikeresen feltöltve.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>imgur.com azonosító feltöltésekor hiba.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>imgur link megnyitása a böngészőben, feltöltés után</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Közvetlen link a képhez</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Késleltés a képernyőkép rögzítése előtt
másodpercben megadva.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>mp</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Képernyőkép mentés a rendszerre</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Képernyőkép másolása a vágólapra</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Megismételés</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>körbevágás</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Képernyőkép körbevágása</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Mentetlen</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Megnyitja a nyomtató párbeszédpanelt, és lehetőséget biztosít a kép kinyomtatására</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Nyomtatási előnézet</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Megnyitja a Nyomtatási előnézet párbeszédpanelt, ahol a kép tájolása megváltoztatható</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Lépték</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Vízjel hozzáadása</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Vízjel hozzáadása a rögzített képhez. Töbszörös vízjelezés is lehetséges.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Nem lehet a képet megjeleníteni</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Mentés mint...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Beágyazott beillesztés</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation type="unfinished">Mentés</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished">Mentés másként</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Másolás</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Képlopás</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Bezár</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Tallózás</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Név</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Verzió</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Mentés másként</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Minden fájl</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Kép mentve</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Kép mentése nem sikerült</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation type="unfinished">Az új képernyőmentéseket automatikusan mentse az alapértelmezett helyre</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished">A mentettlen módosítások elvetése előtt kérdezzen rá a mentésre</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished">Mentés helye és fájlneve</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Tallózás</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation type="unfinished">Rögzített kép mentésének helye</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Tallózás</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Képfogó</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur feltöltő</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Kiemelő</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished">Kép fagyasztása rögzítéskor</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished">Mutassa a nagyítót rögzítéskor</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished">Mutasson a nagyítót, ami nagyítja a háttérképet.
Ez az opció csak akkor működik, ha a
&apos;Kép fagyasztása rögzítéskor&apos; engedélyezve van.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished">Mutassa a vonalzót a rögzítés területén</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished">Vízszintes és függőleges vonalak az asztal széleitől
a rögzítési területen lévő kurzorig.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished">Mutassa a rögzítési terület helyét és méretét</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished">Kurzor színe a rögzítés területén</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished">Kurzor vastagsága a rögzítési területen</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Hozzáad</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Szerkesztő mutatása</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished">Tálcaikon használata</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished">Ha engedélyezve van, a tálcaikon rákerül a tálcára, ha az oprenszer ablakkezelője támogatja ezt a funkciót.
A változtatás érvenyesítéséhez újra kell indítani a programot.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished">Kicsinyítés a tálcára</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished">Bezáráskor lehelyezés a tálcára</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished">Szerkesztő mutatása</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished">Képlopás</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Kép kiválasztása</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished">Megerősítés kérése feltöltés előtt</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>build</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Felhasználó:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished">Vízjel-kép</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Frissítés</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished">Vízjel forgatása</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished">Ha engedélyezve van, a vízjel 45°-kal elforgatva lesz hozzáadva a képhez</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Vízjel beállítások</translation>
    </message>
</context>
</TS>
